@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0603';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
@@ -127,13 +127,13 @@ sub process {}
 sub BUILD {
     my $self = shift;
 
+    return unless @{ $self->notes };
+
     my $iter = combinations( $self->notes, $self->size );
-    while (my $c = $iter->next)
-    {
+    while (my $c = $iter->next) {
         my %dyads = $self->dyads($c);
 
-        if ( $self->chords )
-        {
+        if ( $self->chords ) {
             # Do we know any named chords?
             my @chordname = eval { chordname(@$c) };
 
@@ -144,8 +144,7 @@ sub BUILD {
             $self->chord_names->{"@$c chord_names"} = \@chordname if @chordname;
         }
 
-        if ( $self->integer )
-        {
+        if ( $self->integer ) {
             $self->integer_notation->{"@$c integer_notation"} = {
                 map { $_ => sprintf '%.0f',
                     $self->midikey + $self->semitones * log( ($self->tonic_frequency * (eval $self->_ratio_index->{$_})) / $self->concert ) / log(2)
@@ -153,10 +152,8 @@ sub BUILD {
             };
         }
 
-        if ( $self->justin )
-        {
-            if ( $self->freqs )
-            {
+        if ( $self->justin ) {
+            if ( $self->freqs ) {
                 $self->natural_frequencies->{"@$c natural_frequencies"} = {
                     map { $_ => {
                         sprintf('%.3f', $self->tonic_frequency * eval $self->_ratio_index->{$_})
@@ -165,8 +162,7 @@ sub BUILD {
                     } @$c
                 };
             }
-            if ( $self->interval )
-            {
+            if ( $self->interval ) {
                 $self->natural_intervals->{"@$c natural_intervals"} = {
                     map {
                         $_ => {
@@ -176,16 +172,14 @@ sub BUILD {
                 };
 
             }
-            if ( $self->cents )
-            {
+            if ( $self->cents ) {
                 $self->natural_cents->{"@$c natural_cents"} = {
                     map {
                         $_ => log( eval $dyads{$_}->{natural} ) * $self->temper
                     } keys %dyads };
 
             }
-            if ( $self->prime )
-            {
+            if ( $self->prime ) {
                 $self->natural_prime_factors->{"@$c natural_prime_factors"} = {
                     map {
                         $_ => {
@@ -196,26 +190,22 @@ sub BUILD {
             }
         }
 
-        if ( $self->equalt )
-        {
-            if ( $self->freqs )
-            {
+        if ( $self->equalt ) {
+            if ( $self->freqs ) {
                 $self->eq_tempered_frequencies->{"@$c eq_tempered_frequencies"} = {
                     map {
                         $_ => name2freq( $_ . $self->octave ) || $self->concert * $self->_note_index->{$_}
                     } @$c
                 };
             }
-            if ( $self->interval )
-            {
+            if ( $self->interval ) {
                 $self->eq_tempered_intervals->{"@$c eq_tempered_intervals"} = {
                     map {
                         $_ => $dyads{$_}->{eq_tempered}
                     } keys %dyads
                 };
             }
-            if ( $self->cents )
-            {
+            if ( $self->cents ) {
                 $self->eq_tempered_cents->{"@$c eq_tempered_cents"} = {
                     map {
                         $_ => log( $dyads{$_}->{eq_tempered} ) * $self->temper
@@ -227,8 +217,7 @@ sub BUILD {
 }
 
 
-sub dyads
-{
+sub dyads {
     my $self = shift;
     my ($c) = @_;
 
@@ -274,15 +263,13 @@ sub ratio_factorize {
 }
 
 
-sub by_name
-{
+sub by_name {
     my ( $self, $name ) = @_;
     return $Music::Intervals::Ratios::ratio->{$name};
 }
 
 
-sub by_ratio
-{
+sub by_ratio {
     my ( $self, $ratio ) = @_;
     return $self->_ratio_name_index->{$ratio};
 }
@@ -301,7 +288,7 @@ Music::Intervals - Breakdown of named musical intervals
 
 =head1 VERSION
 
-version 0.0602
+version 0.0603
 
 =head1 SYNOPSIS
 
