@@ -1,5 +1,5 @@
 package Music::Intervals::Numeric;
-$Music::Intervals::Numeric::VERSION = '0.0602';
+$Music::Intervals::Numeric::VERSION = '0.0603';
 our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Breakdown of numeric musical intervals
@@ -43,6 +43,8 @@ sub _build_ratios {
 }
 
 
+sub process {}
+
 sub BUILD {
     my $self = shift;
 
@@ -51,17 +53,14 @@ sub BUILD {
     my %x;
 
     my $iter = combinations( $self->notes, $self->size );
-    while (my $c = $iter->next)
-    {
+    while (my $c = $iter->next) {
         my %dyads = $self->dyads($c);
 
-        if ( $self->freq )
-        {
+        if ( $self->freq ) {
             $self->frequencies->{"@$c"} =
                 { map { $_ => $self->ratios->{$_} } @$c };
         }
-        if ( $self->interval )
-        {
+        if ( $self->interval ) {
             $self->intervals->{"@$c"} = {
                 map {
                     $_ => {
@@ -71,16 +70,14 @@ sub BUILD {
             };
 
         }
-        if ( $self->cent )
-        {
+        if ( $self->cent ) {
             $self->cent_vals->{"@$c"} = {
                 map {
                     $_ => log( eval $dyads{$_} ) * $self->temper
                 } keys %dyads };
 
         }
-        if ( $self->prime )
-        {
+        if ( $self->prime ) {
             $self->prime_factor->{"@$c"} = {
                 map {
                     $_ => {
@@ -93,8 +90,7 @@ sub BUILD {
 }
 
 
-sub dyads
-{
+sub dyads {
     my $self = shift;
     my ($c) = @_;
 
@@ -143,7 +139,7 @@ Music::Intervals::Numeric - Breakdown of numeric musical intervals
 
 =head1 VERSION
 
-version 0.0602
+version 0.0603
 
 =head1 SYNOPSIS
 
